@@ -134,13 +134,16 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
     print("     --- start matching")
     matched_phone_lock_list = []
     matched_last_usage_list = []
+    matched_time_list = []
 
     for idx in prompt_local_datetime_series.index:
         prompt_time = prompt_local_datetime_series[idx]
         # prompt_date = prompt_time.date()
 
         if df_logs_combined.shape[0] == 0:
-            location = np.nan
+            phone_lock = np.nan
+            last_usage = np.nan
+            closest_time = np.nan
         else:
             subset_time_series = df_logs_combined["EVENT_TIME_DATETIME"]
 
@@ -174,11 +177,12 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
             # print("==   {}".format(phone_lock))
 
+        matched_time_list.append(closest_time)
         matched_phone_lock_list.append(phone_lock)
         matched_last_usage_list.append(last_usage)
 
 
-    return matched_phone_lock_list, matched_last_usage_list
+    return matched_phone_lock_list, matched_last_usage_list, matched_time_list
 
 
 def transform(phone_lock_column):
@@ -194,13 +198,14 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
 
     if df_logs_combined.shape[0] > 0:
         # Match the combined parsed intermediate file with prompt feature data frame
-        phone_lock_column, last_usage_column  = match_feature(prompt_local_datetime_series, df_logs_combined)
+        phone_lock_column, last_usage_column, match_time = match_feature(prompt_local_datetime_series, df_logs_combined)
     else:
         phone_lock_column = ["NF"] * len(prompt_local_datetime_series)
         last_usage_column = ["NF"] * len(prompt_local_datetime_series)
+        match_time = ["NF"] * len(prompt_local_datetime_series)
 
     # transform feature
     # result_column_transformed = transform(result_column)
     print("     --- success")
 
-    return phone_lock_column, last_usage_column
+    return phone_lock_column, last_usage_column, match_time
